@@ -14,6 +14,7 @@ from . import (check_artwork, check_dependencies, check_entrypoint,
                check_files, check_addon_branches, check_py3_compatibility,
                check_string, check_url, common, handle_files,
                schema_validation, ValidKodiVersions)
+from .addons.Addon import Addon
 from .addons.Repository import Repository
 from .versions import KodiVersion
 from .record import INFORMATION, Record
@@ -47,17 +48,18 @@ def start(addon_path, args, all_repo_addons, config=None):
     addon_xml = check_files.check_addon_xml(addon_report, addon_path, parsed_xml, args.allow_folder_id_mismatch)
 
     if addon_xml is not None:
-        check_addon_branches.check_for_existing_addon(addon_report, addon_path, all_repo_addons, args.PR,
-                                                      KodiVersion(args.branch))
+        check_addon_branches.check_for_existing_addon(addon_report, Addon(parsed_xml), all_repo_addons, args)
 
-        if not addon_xml.findall("*//broken"):
+        if not addon_xml.findall("*//broken") and \
+           not (addon_xml.findall("*//lifecyclestate") and \
+                addon_xml.find("*//lifecyclestate").attrib.get("type") == "broken"):
             file_index = handle_files.create_file_index(addon_path)
 
             schema_validation.schemas(addon_report, parsed_xml, args.branch)
 
             check_url.check_url(addon_report, parsed_xml)
 
-            check_dependencies.check_addon_dependencies(addon_report, repo_addons, parsed_xml, args.branch)
+            check_dependencies.check_addon_dependencies(addon_report, repo_addons, parsed_xml, args)
 
             check_dependencies.check_reverse_dependencies(addon_report, addon_id, args.branch, all_repo_addons)
 
@@ -88,7 +90,7 @@ def start(addon_path, args, all_repo_addons, config=None):
             else:
                 check_files.check_for_new_language_directory_structure(addon_report, addon_path, supported=False)
 
-            check_string.check_for_invalid_strings_po(addon_report, file_index)
+            check_string.check_for_invalid_strings_po(addon_report, file_index, addon_path)
 
             # Kodi 18 Leia + deprecations
             if config.is_enabled("check_kodi_leia_deprecations"):
