@@ -13,6 +13,7 @@ import xml.etree.ElementTree as ET
 
 from . import handle_files
 from .common import relative_path
+from .common.decorators import posix_only
 from .record import INFORMATION, PROBLEM, WARNING, Record
 from .report import Report
 
@@ -89,18 +90,25 @@ def addon_xml_matches_folder(report: Report, addon_path: str, parsed_xml, folder
             report.add(Record(PROBLEM, "Addon id and folder name does not match."))
 
 
-def check_for_legacy_language_path(report: Report, addon_path: str):
+def check_for_new_language_directory_structure(report: Report, addon_path: str, supported=True):
     """Check whether the language directory structure is new or not
         :addon_path: path to addon folder
+        :supported: if we should error out in case the new language format is not supported
+        by the respective kodiversion
     """
     language_path = os.path.join(addon_path, "resources", "language")
     if os.path.exists(language_path):
         dirs = next(os.walk(language_path))[1]
         for directory in dirs:
-            if "resource.language." not in directory:
+            if "resource.language." not in directory and supported:
                 report.add(Record(
-                    PROBLEM, "Using the old language directory structure, please move to the new one."))
-                break
+                    PROBLEM, "Using the old language directory structure in %s, please move to the new one." %
+                    os.path.join(language_path, directory)))
+            elif "resource.language." in directory and not supported:
+                report.add(Record(
+                    PROBLEM, "Using the new language directory structure in %s for a Kodi version that does not" \
+                             "support it. Please use the old language file struture or move the addon to" \
+                             "an upper branch/kodi version." % os.path.join(language_path, directory)))
 
 
 def check_file_whitelist(report: Report, file_index: list, addon_path: str):
@@ -116,7 +124,7 @@ def check_file_whitelist(report: Report, file_index: list, addon_path: str):
     whitelist = (
         r"\.?(py|xml|gif|png|jpg|jpeg|md|txt|po|json|gitignore|markdown|yml|"
         r"rst|ini|flv|wav|mp4|html|css|lst|pkla|g|template|in|cfg|xsd|directory|"
-        r"help|list|mpeg|pls|info|ttf|xsp|theme|yaml|dict|crt)?$"
+        r"help|list|mpeg|pls|info|ttf|xsp|theme|yaml|dict|crt|ico)?$"
     )
 
     for file in file_index:
@@ -129,6 +137,7 @@ def check_file_whitelist(report: Report, file_index: list, addon_path: str):
                                   relative_path(os.path.join(file["path"], file["name"]))))
 
 
+@posix_only
 def check_file_permission(report: Report, file_index: list):
     """Check whether the files present in addon are marked executable
        or not
