@@ -1,8 +1,16 @@
-from .record import Record, PROBLEM, WARNING
+"""
+    Copyright (C) 2017-2018 Team Kodi
+    This file is part of Kodi - kodi.tv
+
+    SPDX-License-Identifier: GPL-3.0-only
+    See LICENSES/README.md for more information.
+"""
+
+from .record import PROBLEM, WARNING, Record
 from .reporter import ReportManager
 
 
-class Report(object):
+class Report():
     def __init__(self, artifact_name):
         """
         Create a new report for the given artifact. The artifact can be a repo, add-on or file.
@@ -19,7 +27,7 @@ class Report(object):
         :param report: a record or report
         :return: None
         """
-        if type(report) is Record:
+        if isinstance(report, Record):
             for reporter in ReportManager.getEnabledReporters():
                 reporter.report(report)
             if PROBLEM == report.log_level:
